# ragscrape

## scraper

The scraper is written assuming you are running a python virtual environment.

To create the virtual environment:

```
python3 -m venv .venv
source .venv/bin/activate
```

To install the requirements:

```
pip install -r requirements.txt
```

To run the scraper:

```
python3 app.py
```

The scraper right now shows a few different basic scraping techniques and the 
website provides a nice way to compare them.
